==> haskell-non-negative-0.1.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: non-negative
version: 0.1.2
id: non-negative-0.1.2-EnVMs9CRf2v55eMNLW3DNx
key: non-negative-0.1.2-EnVMs9CRf2v55eMNLW3DNx
license: GPL
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://code.haskell.org/~thielema/non-negative/
synopsis: Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.
category: Math
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
indefinite: False
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper
hidden-modules: Numeric.NonNegative.ChunkyPrivate
abi: 9a6edebea4d28aece58eef67374bfe46
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/non-negative-0.1.2
library-dirs: /usr/lib/ghc-8.2.2/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/non-negative-0.1.2
hs-libraries: HSnon-negative-0.1.2-EnVMs9CRf2v55eMNLW3DNx
depends:
    semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q
    utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq
    QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9 base-4.10.1.0
abi-depends: semigroups-0.18.4-mxkGq2xNPcBC0dj8uuk3q=0f8a4b2bc8ee8ce3a5dab66f0eb14e7c
             utility-ht-0.0.14-1SDJ0BtW7GoAaRrxZT3hIq=0362a121972f0b40c9fe893b813ad252
             QuickCheck-2.10.1-pyTUKjDV2C3TaEubSGdV9=77baeaa97e72dac9529ccf150f178180
             base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
haddock-interfaces: /usr/share/doc/haskell-non-negative/html/non-negative.haddock
haddock-html: /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-non-negative-0.1.2-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-non-negative.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: non-negative
version: 0.1.2
id: non-negative-0.1.2-CzJkHCeQuFC7hHKT455tko
key: non-negative-0.1.2-CzJkHCeQuFC7hHKT455tko
license: LicenseRef-GPL
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
author: Henning Thielemann <haskell@henning-thielemann.de>
homepage: http://code.haskell.org/~thielema/non-negative/
synopsis: Non-negative numbers
description:
    Provides a class for non-negative numbers,
    a wrapper which can turn any ordered numeric type into a member of that class,
    and a lazy number type for non-negative numbers
    (a generalization of Peano numbers).
    This library is used by the @event-list@ package.
category: Math
abi: e7efeca0bd431e2db49175a2941bd22c
exposed: True
exposed-modules:
    Numeric.NonNegative.Chunky Numeric.NonNegative.Class
    Numeric.NonNegative.Wrapper
hidden-modules: Numeric.NonNegative.ChunkyPrivate
import-dirs: /usr/lib/ghc-8.4.3/site-local/non-negative-0.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/non-negative-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/non-negative-0.1.2
hs-libraries: HSnon-negative-0.1.2-CzJkHCeQuFC7hHKT455tko
depends:
    utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
abi-depends: utility-ht-0.0.14-CqclJgoUReM5xZSC1dChOW=632b3d47f82599a1155bed59f183b750
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
haddock-interfaces: /usr/share/doc/haskell-non-negative/html/non-negative.haddock
haddock-html: /usr/share/doc/haskell-non-negative/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
